==> kadu_1.2.orig.tar.bz2: kadu-1.2/plugins/speech/translations/speech_es_ES.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_ES" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Speech</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Notificaciones</translation>
    </message>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Maximum number of spoken letters</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Message too long (male)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Message too long (female)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Voice</source>
        <translation>Voz</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation>Frecuencia</translation>
    </message>
    <message>
        <source>Base frequency</source>
        <translation>Frecuencia base</translation>
    </message>
    <message>
        <source>Tempo</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Melody</source>
        <translation>Melodía</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Sonido</translation>
    </message>
    <message>
        <source>Sound system</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>aRts</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Esd</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dsp</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dsp device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Klatt synthesizer (requires dsp)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Speech program</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Test</source>
        <translation>Prueba</translation>
    </message>
    <message>
        <source>Read a text</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SpeechConfigurationWidget</name>
    <message>
        <source>Male format</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Female format</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/speech/translations/speech_es_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>@default</name>
    <message>
        <source>Speech</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Notificaciones</translation>
    </message>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Maximum number of spoken letters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Message too long (male)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Message too long (female)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Voice</source>
        <translation>Voz</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation>Frecuencia</translation>
    </message>
    <message>
        <source>Base frequency</source>
        <translation>Frecuencia base</translation>
    </message>
    <message>
        <source>Tempo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Melody</source>
        <translation>Melodía</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Sonido</translation>
    </message>
    <message>
        <source>Sound system</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>aRts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Esd</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dsp</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dsp device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Klatt synthesizer (requires dsp)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Speech program</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Test</source>
        <translation>Prueba</translation>
    </message>
    <message>
        <source>Read a text</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SpeechConfigurationWidget</name>
    <message>
        <source>Male format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Female format</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
